# FieldOptions14

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**color** | **str** | The color of selected icons. | [optional] 
**icon** | **str** | The icon name used to display the rating. | [optional] 
**max** | **float** | The maximum value for the rating, from 1 to 10 inclusive. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

